@@ -23,10 +23,10 @@ def update_location(thng_id, position=None, timestamp=None, api_key=None):
     return utils.request('PUT', url, data=data, api_key=api_key)
 
 
-def list_locations(thng_id, api_key=None):
+def list_locations(thng_id, api_key=None, **request_kwargs):
     assertions.datatype_str('thng_id', thng_id)
     url = '/thngs/{}/location'.format(thng_id)
-    return utils.request('GET', url, api_key=api_key)
+    return utils.request('GET', url, api_key=api_key, **request_kwargs)
 
 
 def delete_location(thng_id, api_key=None):
